@@ -1,4 +1,4 @@
-from je_editor.utils.editor_content.editor_data import editor_data_dict
+from je_editor.utils.editor_content.editor_content_data import editor_content_data_dict
 
 
 def set_encoding(exec_manager, encoding):
@@ -7,4 +7,4 @@ def set_encoding(exec_manager, encoding):
     :param encoding: which encoding choose
     """
     exec_manager.program_encoding = encoding
-    editor_data_dict["encoding"] = encoding
+    editor_content_data_dict["encoding"] = encoding
